@@ -212,9 +212,7 @@ class BotAI(BotAIInternal):
         :param ignore_resource_requirements:"""
         return await self.client.query_available_abilities(units, ignore_resource_requirements)
 
-    async def expand_now(
-        self, building: UnitTypeId = None, max_distance: float = 10, location: Optional[Point2] = None
-    ):
+    async def expand_now(self, building: UnitTypeId = None, max_distance: int = 10, location: Optional[Point2] = None):
         """Finds the next possible expansion via 'self.get_next_expansion()'. If the target expansion is blocked (e.g. an enemy unit), it will misplace the expansion.
 
         :param building:
@@ -482,7 +480,7 @@ class BotAI(BotAIInternal):
                     return self.calculate_unit_value(UnitTypeId.ARCHON)
             unit_data = self.game_data.units[item_id.value]
             # Cost of morphs is automatically correctly calculated by 'calculate_ability_cost'
-            return self.game_data.calculate_ability_cost(unit_data.creation_ability)
+            return self.game_data.calculate_ability_cost(unit_data.creation_ability.exact_id)
 
         if isinstance(item_id, UpgradeId):
             cost = self.game_data.upgrades[item_id.value].cost
@@ -553,7 +551,7 @@ class BotAI(BotAIInternal):
             if only_check_energy_and_cooldown:
                 return True
             cast_range = self.game_data.abilities[ability_id.value]._proto.cast_range
-            ability_target = self.game_data.abilities[ability_id.value]._proto.target
+            ability_target: int = self.game_data.abilities[ability_id.value]._proto.target
             # Check if target is in range (or is a self cast like stimpack)
             if (
                 ability_target == 1 or ability_target == Target.PointOrNone.value and isinstance(target, Point2)
@@ -783,7 +781,10 @@ class BotAI(BotAIInternal):
         # SUPPLYDEPOTDROP is not in self.game_data.units, so bot_ai should not check the build progress via creation ability (worker abilities)
         if structure_type_value not in self.game_data.units:
             return max((s.build_progress for s in self.structures if s._proto.unit_type in equiv_values), default=0)
-        creation_ability: AbilityData = self.game_data.units[structure_type_value].creation_ability
+        creation_ability_data: AbilityData = self.game_data.units[structure_type_value].creation_ability
+        if creation_ability_data is None:
+            return 0
+        creation_ability: AbilityId = creation_ability_data.exact_id
         max_value = max(
             [s.build_progress for s in self.structures if s._proto.unit_type in equiv_values] +
             [self._abilities_all_units[1].get(creation_ability, 0)],
@@ -841,19 +842,25 @@ class BotAI(BotAIInternal):
             amount_of_CCs_in_queue_and_production: int = self.already_pending(UnitTypeId.COMMANDCENTER)
             amount_of_lairs_morphing: int = self.already_pending(UnitTypeId.LAIR)
 
-
         :param unit_type:
         """
         if isinstance(unit_type, UpgradeId):
             return self.already_pending_upgrade(unit_type)
-        ability = self.game_data.units[unit_type.value].creation_ability
+        try:
+            ability = self.game_data.units[unit_type.value].creation_ability.exact_id
+        except AttributeError:
+            # Hotfix for checking pending archons
+            if unit_type == UnitTypeId.ARCHON:
+                return self._abilities_all_units[0][AbilityId.ARCHON_WARP_TARGET] / 2
+            logger.error(f"Uncaught UnitTypeId: {unit_type}")
+            return 0
         return self._abilities_all_units[0][ability]
 
     def worker_en_route_to_build(self, unit_type: UnitTypeId) -> float:
         """This function counts how many workers are on the way to start the construction a building.
 
         :param unit_type:"""
-        ability = self.game_data.units[unit_type.value].creation_ability
+        ability = self.game_data.units[unit_type.value].creation_ability.exact_id
         return self._worker_orders[ability]
 
     @property_cache_once_per_frame
@@ -867,11 +874,7 @@ class BotAI(BotAIInternal):
                 continue
             for order in worker.orders:
                 # When a construction is resumed, the worker.orders[0].target is the tag of the structure, else it is a Point2
-                target = order.target
-                if isinstance(target, int):
-                    worker_targets.add(target)
-                else:
-                    worker_targets.add(Point2.from_proto(target))
+                worker_targets.add(order.target)
         return self.structures.filter(
             lambda structure: structure.build_progress < 1
             # Redundant check?
@@ -891,7 +894,7 @@ class BotAI(BotAIInternal):
     ) -> bool:
         """Not recommended as this function checks many positions if it "can place" on them until it found a valid
         position. Also if the given position is not placeable, this function tries to find a nearby position to place
-        the structure. Then uses 'self.do' to give the worker the order to start the construction.
+        the structure. Then orders the worker to start the construction.
 
         :param building:
         :param near:
@@ -933,7 +936,7 @@ class BotAI(BotAIInternal):
         """Trains a specified number of units. Trains only one if amount is not specified.
         Warning: currently has issues with warp gate warp ins
 
-        New function. Please report any bugs!
+        Very generic function. Please use with caution and report any bugs!
 
         Example Zerg::
 
@@ -1155,6 +1158,7 @@ class BotAI(BotAIInternal):
 
     def in_map_bounds(self, pos: Union[Point2, tuple, list]) -> bool:
         """Tests if a 2 dimensional point is within the map boundaries of the pixelmaps.
+
         :param pos:"""
         return (
             self.game_info.playable_area.x <= pos[0] <
@@ -1282,6 +1286,7 @@ class BotAI(BotAIInternal):
             print(f"My unit took damage: {unit} took {amount_damage_taken} damage")
 
         :param unit:
+        :param amount_damage_taken:
         """
 
     async def on_enemy_unit_entered_vision(self, unit: Unit):
