@@ -8,7 +8,9 @@ import warnings
 from abc import ABC
 from collections import Counter
 from contextlib import suppress
-from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, List, Set, Tuple, Union, final
+from typing import TYPE_CHECKING, Any
+from typing import Counter as CounterType
+from typing import Dict, Generator, Iterable, List, Set, Tuple, Union, final
 
 import numpy as np
 from loguru import logger
@@ -25,8 +27,9 @@ from sc2.constants import (
     mineral_ids,
 )
 from sc2.data import ActionResult, Race, race_townhalls
-from sc2.game_data import AbilityData, Cost, GameData
+from sc2.game_data import Cost, GameData
 from sc2.game_state import Blip, EffectData, GameState
+from sc2.ids.ability_id import AbilityId
 from sc2.ids.unit_typeid import UnitTypeId
 from sc2.ids.upgrade_id import UpgradeId
 from sc2.pixel_map import PixelMap
@@ -257,21 +260,26 @@ class BotAIInternal(ABC):
 
     @final
     @property_cache_once_per_frame
-    def _abilities_all_units(self) -> Tuple[Counter, Dict[AbilityData, float]]:
+    def _abilities_all_units(self) -> Tuple[CounterType[AbilityId], Dict[AbilityId, float]]:
         """Cache for the already_pending function, includes protoss units warping in,
         all units in production and all structures, and all morphs"""
-        abilities_amount = Counter()
-        max_build_progress: Dict[AbilityData, float] = {}
+        abilities_amount: CounterType[AbilityId] = Counter()
+        max_build_progress: Dict[AbilityId, float] = {}
         unit: Unit
         for unit in self.units + self.structures:
             for order in unit.orders:
-                abilities_amount[order.ability] += 1
+                abilities_amount[order.ability.exact_id] += 1
             if not unit.is_ready:
                 if self.race != Race.Terran or not unit.is_structure:
                     # If an SCV is constructing a building, already_pending would count this structure twice
                     # (once from the SCV order, and once from "not structure.is_ready")
-                    creation_ability: AbilityData = self.game_data.units[unit.type_id.value].creation_ability
-                    abilities_amount[creation_ability] += 1
+                    if unit.type_id == UnitTypeId.ARCHON:
+                        # Hotfix for archons in morph state
+                        creation_ability = AbilityId.ARCHON_WARP_TARGET
+                        abilities_amount[creation_ability] += 2
+                    else:
+                        creation_ability: AbilityId = self.game_data.units[unit.type_id.value].creation_ability.exact_id
+                        abilities_amount[creation_ability] += 1
                     max_build_progress[creation_ability] = max(
                         max_build_progress.get(creation_ability, 0), unit.build_progress
                     )
@@ -280,9 +288,9 @@ class BotAIInternal(ABC):
 
     @final
     @property_cache_once_per_frame
-    def _worker_orders(self) -> Counter:
+    def _worker_orders(self) -> CounterType[AbilityId]:
         """ This function is used internally, do not use! It is to store all worker abilities. """
-        abilities_amount = Counter()
+        abilities_amount: CounterType[AbilityId] = Counter()
         structures_in_production: Set[Union[Point2, int]] = set()
         for structure in self.structures:
             if structure.type_id in TERRAN_STRUCTURES_REQUIRE_SCV:
@@ -292,13 +300,9 @@ class BotAIInternal(ABC):
             for order in worker.orders:
                 # Skip if the SCV is constructing (not isinstance(order.target, int))
                 # or resuming construction (isinstance(order.target, int))
-                is_int = isinstance(order.target, int)
-                if (
-                    is_int and order.target in structures_in_production
-                    or not is_int and Point2.from_proto(order.target) in structures_in_production
-                ):
+                if order.target in structures_in_production:
                     continue
-                abilities_amount[order.ability] += 1
+                abilities_amount[order.ability.exact_id] += 1
         return abilities_amount
 
     @final
@@ -478,7 +482,7 @@ class BotAIInternal(ABC):
         # Set attributes from new state before on_step."""
         self.state: GameState = state  # See game_state.py
         # update pathing grid, which unfortunately is in GameInfo instead of GameState
-        self.game_info.pathing_grid: PixelMap = PixelMap(proto_game_info.game_info.start_raw.pathing_grid, in_bits=True)
+        self.game_info.pathing_grid = PixelMap(proto_game_info.game_info.start_raw.pathing_grid, in_bits=True)
         # Required for events, needs to be before self.units are initialized so the old units are stored
         self._units_previous_map: Dict[int, Unit] = {unit.tag: unit for unit in self.units}
         self._structures_previous_map: Dict[int, Unit] = {structure.tag: structure for structure in self.structures}
@@ -649,7 +653,6 @@ class BotAIInternal(ABC):
         proto_game_info = await self.client._execute(game_info=sc_pb.RequestGameInfo())
         self._prepare_step(gs, proto_game_info)
         await self.issue_events()
-        # await self.on_step(-1)
 
     @final
     async def issue_events(self):
@@ -731,18 +734,16 @@ class BotAIInternal(ABC):
                 await self.on_enemy_unit_entered_vision(enemy_structure)
 
         # Call events for enemy unit left vision
-        enemy_units_left_vision: Set[int] = set(self._enemy_units_previous_map.keys()) - self.enemy_units.tags
+        enemy_units_left_vision: Set[int] = set(self._enemy_units_previous_map) - self.enemy_units.tags
         for enemy_unit_tag in enemy_units_left_vision:
             await self.on_enemy_unit_left_vision(enemy_unit_tag)
-        enemy_structures_left_vision: Set[int] = (
-            set(self._enemy_structures_previous_map.keys()) - self.enemy_structures.tags
-        )
+        enemy_structures_left_vision: Set[int] = (set(self._enemy_structures_previous_map) - self.enemy_structures.tags)
         for enemy_structure_tag in enemy_structures_left_vision:
             await self.on_enemy_unit_left_vision(enemy_structure_tag)
 
     @final
     async def _issue_unit_dead_events(self):
-        for unit_tag in self.state.dead_units & set(self._all_units_previous_map.keys()):
+        for unit_tag in self.state.dead_units & set(self._all_units_previous_map):
             await self.on_unit_destroyed(unit_tag)
 
     # DISTANCE CALCULATION
